@@ -24,7 +24,6 @@
 
 #include <KXmlGuiWindow>
 
-class QSignalMapper;
 class QAction;
 class KToggleAction;
 
@@ -109,8 +108,6 @@ private:
     void setupActions();
     void setupEditToolbarActions();
 
-    QSignalMapper * tempMapper;		// Temporary pointer.
-
     QAction * gameAction (const QString & name, const int code,
                           const QString & text, const QString & toolTip,
                           const QString & whatsThis, const QKeySequence & key);
@@ -134,6 +131,10 @@ private:
                           const QKeySequence & shortcut, const int code,
                           const bool mover = false);
 
+    void keyControlDebug (const QString & name, const QString & text,
+                          const QKeySequence & shortcut, const int code,
+                          const bool mover = false);
+
     bool startupOK;
 
     KGrGame     *   game;		// Overall control of the gameplay.
